pub struct Inputs {
pub dirs: Vec<PathBuf>,
pub file_regex: Option<String>,
pub files: Vec<PathBuf>,
}Expand description
Source files that trigger re-generation when they change.
At least one of dirs or files should be non-empty.
Fields
dirs: Vec<PathBuf>Directories to watch for added/removed files.
file_regex: Option<String>Optional regex filter applied to filenames inside dirs.
files: Vec<PathBuf>Individual files to watch (used when the input is a single spec file).